@@ -167,7 +167,7 @@ class UUIDField(Field):
     db_field = 'uuid'
 
     def db_value(self, value):
-        return str(value)
+        return None if value is None else str(value) 
 
     def python_value(self, value):
         return uuid.UUID(value)
